@@ -35,7 +35,7 @@ class pdtLocale_base(object):
                     'dateFormats', 'dateSep', 'dayOffsets', 'dp_order', 
                     'localeID', 'meridian', 'Modifiers', 're_sources', 're_values', 
                     'shortMonths', 'shortWeekdays', 'timeFormats', 'timeSep', 'units', 
-                    'uses24', 'usesMeridian' ]
+                    'uses24', 'usesMeridian', 'numbers' ]
 
     def __init__(self):
         self.localeID      = None   # don't use a unicode string
@@ -79,14 +79,23 @@ class pdtLocale_base(object):
 
         self.dp_order = [ 'm', 'd', 'y' ]
 
+        # Used to parse expressions like "in 5 hours"
+        self.numbers = { 'zero': 0, 'one': 1, 'two': 2, 'three': 3, 'four': 4,
+                         'five': 5, 'six': 6, 'seven': 7, 'eight': 8, 'nine': 9,
+                         'ten': 10, 'eleven': 11, 'twelve': 12, 'thirtheen': 13,
+                         'fourteen': 14, 'fifteen': 15, 'sixteen': 16,
+                         'seventeen': 17, 'eighteen': 18, 'nineteen': 19,
+                         'twenty': 20 }
+
+
           # this will be added to re_values later
-        self.units = { 'seconds': [ 'second', 'sec' ],
-                       'minutes': [ 'minute', 'min' ],
-                       'hours':   [ 'hour',   'hr'  ],
-                       'days':    [ 'day',    'dy'  ],
-                       'weeks':   [ 'week',   'wk'  ],
-                       'months':  [ 'month',  'mth' ],
-                       'years':   [ 'year',   'yr'  ],
+        self.units = { 'seconds': [ 'second', 'seconds', 'sec', 's' ],
+                       'minutes': [ 'minute', 'minutes', 'min', 'm' ],
+                       'hours':   [ 'hour',   'hours',   'hr',  'h' ],
+                       'days':    [ 'day',    'days',    'dy',  'd' ],
+                       'weeks':   [ 'week',   'weeks',   'wk',  'w' ],
+                       'months':  [ 'month',  'months',  'mth'      ],
+                       'years':   [ 'year',   'years',   'yr',  'y' ],
                      }
 
           # text constants to be used by later regular expressions
@@ -95,7 +104,7 @@ class pdtLocale_base(object):
                                'rangeseperator': '-',
                                'daysuffix':      'rd|st|nd|th',
                                'meridian':       'am|pm|a.m.|p.m.|a|p',
-                               'qunits':         'h|m|s|d|w|m|y',
+                               'qunits':         'h|m|s|d|w|y',
                                'now':            [ 'now' ],
                              }
 
@@ -148,9 +157,15 @@ class pdtLocale_icu(pdtLocale_base):
         self.icu = None
 
         if pyicu is not None:
+            if localeID is None:
+              localeID = 'en_US'
             self.icu = pyicu.Locale(localeID)
 
         if self.icu is not None:
+            # grab spelled out format of all numbers from 0 to 100
+            rbnf = pyicu.RuleBasedNumberFormat(pyicu.URBNFRuleSetTag.SPELLOUT, self.icu)
+            self.numbers = dict([(rbnf.format(i), i) for i in xrange(0, 100)])
+
             self.symbols = pyicu.DateFormatSymbols(self.icu)
 
               # grab ICU list of weekdays, skipping first entry which
@@ -195,7 +210,7 @@ class pdtLocale_icu(pdtLocale_base):
             s = self.timeFormats['short']
 
             self.usesMeridian = 'a' in s
-            slef.uses24       = 'H' in s
+            self.uses24       = 'H' in s
 
               # '11:45 AM' or '11:45'
             s = o.format(datetime.datetime(2003, 10, 30, 11, 45))
@@ -365,12 +380,12 @@ class pdtLocale_de(pdtLocale_base):
         self.units['seconds'] = [ 'sekunden', 'sek',  's' ]
         self.units['minutes'] = [ 'minuten',  'min' , 'm' ]
         self.units['hours']   = [ 'stunden',  'std',  'h' ]
-        self.units['days']    = [ 'tage',     't' ]
-        self.units['weeks']   = [ 'wochen',   'w' ]
-        self.units['months']  = [ 'monate' ]  #the short version would be a capital M,
-                                              #as I understand it we can't distinguis
-                                              #between m for minutes and M for months.
-        self.units['years']   = [ 'jahre',    'j' ]
+        self.units['days']    = [ 'tag',  'tage',     't' ]
+        self.units['weeks']   = [ 'wochen',           'w' ]
+        self.units['months']  = [ 'monat', 'monate' ]  #the short version would be a capital M,
+                                                       #as I understand it we can't distinguis
+                                                       #between m for minutes and M for months.
+        self.units['years']   = [ 'jahr', 'jahre',    'j' ]
 
         self.re_values['specials']       = 'am|dem|der|im|in|den|zum'
         self.re_values['timeseperator']  = ':'
